Class: Aws::SecurityLake::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SecurityLake::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-securitylake/client.rb,
sig/client.rbs
Overview
An API client for SecurityLake. To construct a client, you need to configure a :region and :credentials.
client = Aws::SecurityLake::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAwsLogSourceResponseSuccess, _CreateCustomLogSourceResponseSuccess, _CreateDataLakeExceptionSubscriptionResponseSuccess, _CreateDataLakeOrganizationConfigurationResponseSuccess, _CreateDataLakeResponseSuccess, _CreateSubscriberNotificationResponseSuccess, _CreateSubscriberResponseSuccess, _DeleteAwsLogSourceResponseSuccess, _DeleteCustomLogSourceResponseSuccess, _DeleteDataLakeExceptionSubscriptionResponseSuccess, _DeleteDataLakeOrganizationConfigurationResponseSuccess, _DeleteDataLakeResponseSuccess, _DeleteSubscriberNotificationResponseSuccess, _DeleteSubscriberResponseSuccess, _DeregisterDataLakeDelegatedAdministratorResponseSuccess, _GetDataLakeExceptionSubscriptionResponseSuccess, _GetDataLakeOrganizationConfigurationResponseSuccess, _GetDataLakeSourcesResponseSuccess, _GetSubscriberResponseSuccess, _ListDataLakeExceptionsResponseSuccess, _ListDataLakesResponseSuccess, _ListLogSourcesResponseSuccess, _ListSubscribersResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterDataLakeDelegatedAdministratorResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateDataLakeExceptionSubscriptionResponseSuccess, _UpdateDataLakeResponseSuccess, _UpdateSubscriberNotificationResponseSuccess, _UpdateSubscriberResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_aws_log_source(params = {}) ⇒ Types::CreateAwsLogSourceResponse
Adds a natively supported Amazon Web Services service as an Amazon Security Lake source.
-
#create_custom_log_source(params = {}) ⇒ Types::CreateCustomLogSourceResponse
Adds a third-party custom source in Amazon Security Lake, from the Amazon Web Services Region where you want to create a custom source.
-
#create_data_lake(params = {}) ⇒ Types::CreateDataLakeResponse
Initializes an Amazon Security Lake instance with the provided (or default) configuration.
-
#create_data_lake_exception_subscription(params = {}) ⇒ Struct
Creates the specified notification subscription in Amazon Security Lake for the organization you specify.
-
#create_data_lake_organization_configuration(params = {}) ⇒ Struct
Automatically enables Amazon Security Lake for new member accounts in your organization.
-
#create_subscriber(params = {}) ⇒ Types::CreateSubscriberResponse
Creates a subscriber for accounts that are already enabled in Amazon Security Lake.
-
#create_subscriber_notification(params = {}) ⇒ Types::CreateSubscriberNotificationResponse
Notifies the subscriber when new data is written to the data lake for the sources that the subscriber consumes in Security Lake.
-
#delete_aws_log_source(params = {}) ⇒ Types::DeleteAwsLogSourceResponse
Removes a natively supported Amazon Web Services service as an Amazon Security Lake source.
-
#delete_custom_log_source(params = {}) ⇒ Struct
Removes a custom log source from Amazon Security Lake, to stop sending data from the custom source to Security Lake.
-
#delete_data_lake(params = {}) ⇒ Struct
When you disable Amazon Security Lake from your account, Security Lake is disabled in all Amazon Web Services Regions and it stops collecting data from your sources.
-
#delete_data_lake_exception_subscription(params = {}) ⇒ Struct
Deletes the specified notification subscription in Amazon Security Lake for the organization you specify.
-
#delete_data_lake_organization_configuration(params = {}) ⇒ Struct
Turns off automatic enablement of Amazon Security Lake for member accounts that are added to an organization in Organizations.
-
#delete_subscriber(params = {}) ⇒ Struct
Deletes the subscription permission and all notification settings for accounts that are already enabled in Amazon Security Lake.
-
#delete_subscriber_notification(params = {}) ⇒ Struct
Deletes the specified subscription notification in Amazon Security Lake for the organization you specify.
-
#deregister_data_lake_delegated_administrator(params = {}) ⇒ Struct
Deletes the Amazon Security Lake delegated administrator account for the organization.
-
#get_data_lake_exception_subscription(params = {}) ⇒ Types::GetDataLakeExceptionSubscriptionResponse
Retrieves the protocol and endpoint that were provided when subscribing to Amazon SNS topics for exception notifications.
-
#get_data_lake_organization_configuration(params = {}) ⇒ Types::GetDataLakeOrganizationConfigurationResponse
Retrieves the configuration that will be automatically set up for accounts added to the organization after the organization has onboarded to Amazon Security Lake.
-
#get_data_lake_sources(params = {}) ⇒ Types::GetDataLakeSourcesResponse
Retrieves a snapshot of the current Region, including whether Amazon Security Lake is enabled for those accounts and which sources Security Lake is collecting data from.
-
#get_subscriber(params = {}) ⇒ Types::GetSubscriberResponse
Retrieves the subscription information for the specified subscription ID.
-
#list_data_lake_exceptions(params = {}) ⇒ Types::ListDataLakeExceptionsResponse
Lists the Amazon Security Lake exceptions that you can use to find the source of problems and fix them.
-
#list_data_lakes(params = {}) ⇒ Types::ListDataLakesResponse
Retrieves the Amazon Security Lake configuration object for the specified Amazon Web Services Regions.
-
#list_log_sources(params = {}) ⇒ Types::ListLogSourcesResponse
Retrieves the log sources.
-
#list_subscribers(params = {}) ⇒ Types::ListSubscribersResponse
Lists all subscribers for the specific Amazon Security Lake account ID.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region.
-
#register_data_lake_delegated_administrator(params = {}) ⇒ Struct
Designates the Amazon Security Lake delegated administrator account for the organization.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region.
-
#update_data_lake(params = {}) ⇒ Types::UpdateDataLakeResponse
You can use
UpdateDataLaketo specify where to store your security data, how it should be encrypted at rest and for how long. -
#update_data_lake_exception_subscription(params = {}) ⇒ Struct
Updates the specified notification subscription in Amazon Security Lake for the organization you specify.
-
#update_subscriber(params = {}) ⇒ Types::UpdateSubscriberResponse
Updates an existing subscription for the given Amazon Security Lake account ID.
-
#update_subscriber_notification(params = {}) ⇒ Types::UpdateSubscriberNotificationResponse
Updates an existing notification method for the subscription (SQS or HTTPs endpoint) or switches the notification subscription endpoint for a subscriber.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-securitylake/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2032 2033 2034 |
# File 'lib/aws-sdk-securitylake/client.rb', line 2032 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2035 2036 2037 |
# File 'lib/aws-sdk-securitylake/client.rb', line 2035 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2005 2006 2007 2008 2009 2010 2011 2012 2013 2014 2015 2016 2017 2018 2019 2020 2021 |
# File 'lib/aws-sdk-securitylake/client.rb', line 2005 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SecurityLake') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-securitylake' context[:gem_version] = '1.59.0' Seahorse::Client::Request.new(handlers, context) end |
#create_aws_log_source(params = {}) ⇒ Types::CreateAwsLogSourceResponse
Adds a natively supported Amazon Web Services service as an Amazon Security Lake source. Enables source types for member accounts in required Amazon Web Services Regions, based on the parameters you specify. You can choose any source type in any Region for either accounts that are part of a trusted organization or standalone accounts. Once you add an Amazon Web Services service as a source, Security Lake starts collecting logs and events from it.
You can use this API only to enable natively supported Amazon Web
Services services as a source. Use CreateCustomLogSource to enable
data collection from a custom source.
86 |
# File 'sig/client.rbs', line 86
def create_aws_log_source: (
|
#create_custom_log_source(params = {}) ⇒ Types::CreateCustomLogSourceResponse
Adds a third-party custom source in Amazon Security Lake, from the Amazon Web Services Region where you want to create a custom source. Security Lake can collect logs and events from third-party custom sources. After creating the appropriate IAM role to invoke Glue crawler, use this API to add a custom source name in Security Lake. This operation creates a partition in the Amazon S3 bucket for Security Lake as the target location for log files from the custom source. In addition, this operation also creates an associated Glue table and an Glue crawler.
103 |
# File 'sig/client.rbs', line 103
def create_custom_log_source: (
|
#create_data_lake(params = {}) ⇒ Types::CreateDataLakeResponse
Initializes an Amazon Security Lake instance with the provided (or
default) configuration. You can enable Security Lake in Amazon Web
Services Regions with customized settings before enabling log
collection in Regions. To specify particular Regions, configure these
Regions using the configurations parameter. If you have already
enabled Security Lake in a Region when you call this command, the
command will update the Region if you provide new configuration
parameters. If you have not already enabled Security Lake in the
Region when you call this API, it will set up the data lake in the
Region with the specified configurations.
When you enable Security Lake, it starts ingesting security data after
the CreateAwsLogSource call and after you create subscribers using
the CreateSubscriber API. This includes ingesting security data from
sources, storing data, and making data accessible to subscribers.
Security Lake also enables all the existing settings and resources
that it stores or maintains for your Amazon Web Services account in
the current Region, including security log and event data. For more
information, see the Amazon Security Lake User Guide.
124 |
# File 'sig/client.rbs', line 124
def create_data_lake: (
|
#create_data_lake_exception_subscription(params = {}) ⇒ Struct
Creates the specified notification subscription in Amazon Security Lake for the organization you specify. The notification subscription is created for exceptions that cannot be resolved by Security Lake automatically.
142 |
# File 'sig/client.rbs', line 142
def create_data_lake_exception_subscription: (
|
#create_data_lake_organization_configuration(params = {}) ⇒ Struct
Automatically enables Amazon Security Lake for new member accounts in your organization. Security Lake is not automatically enabled for any existing member accounts in your organization.
This operation merges the new data lake organization configuration with the existing configuration for Security Lake in your organization. If you want to create a new data lake organization configuration, you must delete the existing one using DeleteDataLakeOrganizationConfiguration.
153 |
# File 'sig/client.rbs', line 153
def create_data_lake_organization_configuration: (
|
#create_subscriber(params = {}) ⇒ Types::CreateSubscriberResponse
Creates a subscriber for accounts that are already enabled in Amazon Security Lake. You can create a subscriber with access to data in the current Amazon Web Services Region.
173 |
# File 'sig/client.rbs', line 173
def create_subscriber: (
|
#create_subscriber_notification(params = {}) ⇒ Types::CreateSubscriberNotificationResponse
Notifies the subscriber when new data is written to the data lake for the sources that the subscriber consumes in Security Lake. You can create only one subscriber notification per subscriber.
198 |
# File 'sig/client.rbs', line 198
def create_subscriber_notification: (
|
#delete_aws_log_source(params = {}) ⇒ Types::DeleteAwsLogSourceResponse
Removes a natively supported Amazon Web Services service as an Amazon Security Lake source. You can remove a source for one or more Regions. When you remove the source, Security Lake stops collecting data from that source in the specified Regions and accounts, and subscribers can no longer consume new data from the source. However, subscribers can still consume data that Security Lake collected from the source before removal.
You can choose any source type in any Amazon Web Services Region for either accounts that are part of a trusted organization or standalone accounts.
209 |
# File 'sig/client.rbs', line 209
def delete_aws_log_source: (
|
#delete_custom_log_source(params = {}) ⇒ Struct
Removes a custom log source from Amazon Security Lake, to stop sending data from the custom source to Security Lake.
225 |
# File 'sig/client.rbs', line 225
def delete_custom_log_source: (
|
#delete_data_lake(params = {}) ⇒ Struct
When you disable Amazon Security Lake from your account, Security Lake is disabled in all Amazon Web Services Regions and it stops collecting data from your sources. Also, this API automatically takes steps to remove the account from Security Lake. However, Security Lake retains all of your existing settings and the resources that it created in your Amazon Web Services account in the current Amazon Web Services Region.
The DeleteDataLake operation does not delete the data that is stored
in your Amazon S3 bucket, which is owned by your Amazon Web Services
account. For more information, see the Amazon Security Lake User
Guide.
235 |
# File 'sig/client.rbs', line 235
def delete_data_lake: (
|
#delete_data_lake_exception_subscription(params = {}) ⇒ Struct
Deletes the specified notification subscription in Amazon Security Lake for the organization you specify.
244 |
# File 'sig/client.rbs', line 244
def delete_data_lake_exception_subscription: (
|
#delete_data_lake_organization_configuration(params = {}) ⇒ Struct
Turns off automatic enablement of Amazon Security Lake for member accounts that are added to an organization in Organizations. Only the delegated Security Lake administrator for an organization can perform this operation. If the delegated Security Lake administrator performs this operation, new member accounts won't automatically contribute data to the data lake.
252 |
# File 'sig/client.rbs', line 252
def delete_data_lake_organization_configuration: (
|
#delete_subscriber(params = {}) ⇒ Struct
Deletes the subscription permission and all notification settings for
accounts that are already enabled in Amazon Security Lake. When you
run DeleteSubscriber, the subscriber will no longer consume data
from Security Lake and the subscriber is removed. This operation
deletes the subscriber and removes access to data in the current
Amazon Web Services Region.
271 |
# File 'sig/client.rbs', line 271
def delete_subscriber: (
|
#delete_subscriber_notification(params = {}) ⇒ Struct
Deletes the specified subscription notification in Amazon Security Lake for the organization you specify.
280 |
# File 'sig/client.rbs', line 280
def delete_subscriber_notification: (
|
#deregister_data_lake_delegated_administrator(params = {}) ⇒ Struct
Deletes the Amazon Security Lake delegated administrator account for the organization. This API can only be called by the organization management account. The organization management account cannot be the delegated administrator account.
289 |
# File 'sig/client.rbs', line 289
def deregister_data_lake_delegated_administrator: (
|
#get_data_lake_exception_subscription(params = {}) ⇒ Types::GetDataLakeExceptionSubscriptionResponse
Retrieves the protocol and endpoint that were provided when subscribing to Amazon SNS topics for exception notifications.
300 |
# File 'sig/client.rbs', line 300
def get_data_lake_exception_subscription: (
|
#get_data_lake_organization_configuration(params = {}) ⇒ Types::GetDataLakeOrganizationConfigurationResponse
Retrieves the configuration that will be automatically set up for accounts added to the organization after the organization has onboarded to Amazon Security Lake. This API does not take input parameters.
309 |
# File 'sig/client.rbs', line 309
def get_data_lake_organization_configuration: (
|
#get_data_lake_sources(params = {}) ⇒ Types::GetDataLakeSourcesResponse
Retrieves a snapshot of the current Region, including whether Amazon Security Lake is enabled for those accounts and which sources Security Lake is collecting data from.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def get_data_lake_sources: (
|
#get_subscriber(params = {}) ⇒ Types::GetSubscriberResponse
Retrieves the subscription information for the specified subscription ID. You can get information about a specific subscriber.
332 |
# File 'sig/client.rbs', line 332
def get_subscriber: (
|
#list_data_lake_exceptions(params = {}) ⇒ Types::ListDataLakeExceptionsResponse
Lists the Amazon Security Lake exceptions that you can use to find the source of problems and fix them.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
343 |
# File 'sig/client.rbs', line 343
def list_data_lake_exceptions: (
|
#list_data_lakes(params = {}) ⇒ Types::ListDataLakesResponse
Retrieves the Amazon Security Lake configuration object for the specified Amazon Web Services Regions. You can use this operation to determine whether Security Lake is enabled for a Region.
355 |
# File 'sig/client.rbs', line 355
def list_data_lakes: (
|
#list_log_sources(params = {}) ⇒ Types::ListLogSourcesResponse
Retrieves the log sources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
366 |
# File 'sig/client.rbs', line 366
def list_log_sources: (
|
#list_subscribers(params = {}) ⇒ Types::ListSubscribersResponse
Lists all subscribers for the specific Amazon Security Lake account ID. You can retrieve a list of subscriptions associated with a specific organization or Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
383 |
# File 'sig/client.rbs', line 383
def list_subscribers: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves the tags (keys and values) that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region.
394 |
# File 'sig/client.rbs', line 394
def list_tags_for_resource: (
|
#register_data_lake_delegated_administrator(params = {}) ⇒ Struct
Designates the Amazon Security Lake delegated administrator account for the organization. This API can only be called by the organization management account. The organization management account cannot be the delegated administrator account.
403 |
# File 'sig/client.rbs', line 403
def register_data_lake_delegated_administrator: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates one or more tags that are associated with an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region. A tag is a label that you can define and associate with Amazon Web Services resources. Each tag consists of a required tag key and an associated tag value. A tag key is a general label that acts as a category for a more specific tag value. A tag value acts as a descriptor for a tag key. Tags can help you identify, categorize, and manage resources in different ways, such as by owner, environment, or other criteria. For more information, see Tagging Amazon Security Lake resources in the Amazon Security Lake User Guide.
412 |
# File 'sig/client.rbs', line 412
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags (keys and values) from an Amazon Security Lake resource: a subscriber, or the data lake configuration for your Amazon Web Services account in a particular Amazon Web Services Region.
427 |
# File 'sig/client.rbs', line 427
def untag_resource: (
|
#update_data_lake(params = {}) ⇒ Types::UpdateDataLakeResponse
You can use UpdateDataLake to specify where to store your security
data, how it should be encrypted at rest and for how long. You can add
a Rollup Region to consolidate data from multiple Amazon Web
Services Regions, replace default encryption (SSE-S3) with Customer
Manged Key, or specify transition and expiration actions through
storage Lifecycle management. The UpdateDataLake API works as
an "upsert" operation that performs an insert if the specified item
or record does not exist, or an update if it already exists. Security
Lake securely stores your data at rest using Amazon Web Services
encryption solutions. For more details, see Data protection in Amazon
Security Lake.
For example, omitting the key encryptionConfiguration from a Region
that is included in an update call that currently uses KMS will leave
that Region's KMS key in place, but specifying
encryptionConfiguration: {kmsKeyId: 'S3_MANAGED_KEY'} for that same
Region will reset the key to S3-managed.
For more details about lifecycle management and how to update retention settings for one or more Regions after enabling Security Lake, see the Amazon Security Lake User Guide.
438 |
# File 'sig/client.rbs', line 438
def update_data_lake: (
|
#update_data_lake_exception_subscription(params = {}) ⇒ Struct
Updates the specified notification subscription in Amazon Security Lake for the organization you specify.
450 |
# File 'sig/client.rbs', line 450
def update_data_lake_exception_subscription: (
|
#update_subscriber(params = {}) ⇒ Types::UpdateSubscriberResponse
Updates an existing subscription for the given Amazon Security Lake account ID. You can update a subscriber by changing the sources that the subscriber consumes data from.
462 |
# File 'sig/client.rbs', line 462
def update_subscriber: (
|
#update_subscriber_notification(params = {}) ⇒ Types::UpdateSubscriberNotificationResponse
Updates an existing notification method for the subscription (SQS or HTTPs endpoint) or switches the notification subscription endpoint for a subscriber.
481 |
# File 'sig/client.rbs', line 481
def update_subscriber_notification: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2025 2026 2027 |
# File 'lib/aws-sdk-securitylake/client.rb', line 2025 def waiter_names [] end |